#
# spec file for package vifm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           vifm
Version:        0.8.2
Release:        1.10
Summary:        Ncurses based file manager with vi like keybindings
License:        GPL-2.0+
Group:          Productivity/File utilities
Url:            http://%{name}.info
Source:         http://prdownloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
BuildRequires:  file-devel
BuildRequires:  groff
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
%if 0%{?suse_version} > 1110
BuildRequires:  pkgconfig(x11)
%else
BuildRequires:  xorg-x11-devel
%endif

%description
Vifm is a ncurses based file manager with vi like keybindings that allow complete
keyboard control over your files without having to learn a new set of commands.
It supports UTF-8, a quick file view similar to midnight commander's quick view,
and configurable color schemes.

%prep
%setup -q

%build
%configure \
	--with-curses \
	--with-libmagic \
	--without-gtk \
	--disable-developer
make %{?_smp_mflags}
gzip -9c ChangeLog > ChangeLog.gz

%install
make install DESTDIR="%{?buildroot}"
%if 0%{?suse_version}
%suse_update_desktop_file %{name}
%endif
rm -rf %{buildroot}%{_datadir}/doc/vifm/*
rm -rf %{buildroot}%{_datadir}/vifm/vifmrc-osx
rm -rf %{buildroot}%{_datadir}/vifm/vim-doc/doc/tags
rm -rf %{buildroot}%{_datadir}/vifm/vim-doc/doc/vifm-app.txt

%files
%defattr(-,root,root)
%doc AUTHORS BUGS ChangeLog.* COPYING README TODO
%doc %{_datadir}/%{name}/%{name}-help.txt
%dir %{_datadir}/%{name}
%{_bindir}/*
%{_datadir}/%{name}/vim
%{_datadir}/%{name}/%{name}rc
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*
%{_datadir}/vifm/colors/

%changelog
* Sat Jul 16 2016 mvetter@suse.com
- Update to version 0.8.2:
  * key suggestions in the interface on ambiguous input (e.g. "g");
  * helpful shortcuts for dialogs (for sort dialog in particular);
  * key descriptions in :map menus and %%z macro for 'statusline' to display some tips;
  * description of all :commands, 'options' and their values for new multiline
  version of wildmenu;
  * ANDing, ORing and negating patterns for matching files and new mime-type
  matcher;
  * file prefixes and suffixes can now be multi-byte, which with extended
  'classify' option allows specifying "icons" via custom fonts;
  * search result highlighting, enabled completion and a way to export the list
  for menus;
  * an indication of pattern correctness and match state for interactive prompts.
  * :select and :unselect commands to perform automatic file selection (possibly
  by using output of external application);
  * cancellation (handling of Ctrl-C) for quick view and view mode loading.
* Sat Jul  2 2016 mvetter@suse.com
- Update to version 0.8.2 Beta 1:
  * Key suggestions in the interface on ambiguous input (e.g. g).
  * Helpful shortcuts for dialogs (for sort dialog in particular).
  * Key descriptions in :map menus and %%z macro for 'statusline' to display some tips.
  * Description of all :commands, 'options' and their values for new multiline version of wildmenu.
  * ANDing, ORing and negating patterns for matching files and new mime-type matcher.
  * File prefixes and suffixes can now be multi-byte, which with extended 'classify' option allows specifying "icons" via custom fonts.
  * Search result highlighting, enabled completion and a way to export the list for menus.
  * An indication of pattern correctness and match state for interactive prompts.
  * :select and :unselect commands to perform automatic file selection (possibly by using output of external application).
  * Cancellation (handling of Ctrl-C) for quick view and view mode loading.
  * For the complete list see: https://vifm.info/news/2016-07-02.shtml
* Thu Feb 11 2016 mvetter@suse.com
- Update to version 0.8.1a
  This is a bugfix release to primarily address messed up single-executable builds for Windows.
  Other bugfixes:
  * Fixed storing filetypes in vifminfo, which could create duplicates.
  * Fixed --with-dyn-x11 configuration option, which failed to enable dynamic use of the library.
  * Fixed using plugin in neovim, which has broken system() and :! commands.
* Sun Jan 17 2016 mvetter@suse.com
- Update to version 0.8.1
  * Added local options, which work until directory change.
  * Added named bookmarks (paths are associated with tags).
  * Added autocommands (with DirEnter event).
  * Added ability to sort by regexp-extracted part of file name.
  * Added builtin directory preview (similar to tree).
  * Added a way to communicate menu contents to Vim quickfix.
  * Added "more" mode that is used to handle status bar content that doesn't fit on the screen.
  * IPC got new (safe) implementation with listing/targeting of active instances, it's enabled by default again.
  * Updating local view settings from vifmrc now affects both panes (:windo is not necessary).
  * More predictive cursor updates on directory reload.
  * Improvements related to expression and command parsing.
- Remove vifm_utils_nix_dynamic_page_size_for_powerpc.patch:
  Got upstreamed
* Thu Aug 27 2015 normand@linux.vnet.ibm.com
- new patch to avoid build failure for PowerPC architectures
  vifm_utils_nix_dynamic_page_size_for_powerpc.patch
* Fri Jul 10 2015 mvetter@suse.com
- Update to version 0.8
  * Added filename specific highlight (with a script to convert ls options).
  * Added custom views, which contrary to regular views can contain files that do not belong to the same directory.
  * Added job bar to display active backgrounded file operations.
  * Added command-line mode abbreviations.
  * Added global configuration and color schemes directory.
  * Added live search match highlighting.
  * Added optional per-file progress for file operations.
  * Added full path patterns ({{globs}} and //regexp//).
  * Added command-line options to control file/directory selection and selection processing to make it easier to use vifm as a file picker.
  * Color schemes got ".vifm" extension, but the old-style names will still work for now.
  * XDG specification support.
  * Ability to use terminal applications to preview graphics (e.g. w3mimgdisplay).
* Wed Apr  8 2015 g.bluehut@gmail.com
- Update projects website URL
* Tue Apr  7 2015 g.bluehut@gmail.com
- Use suse_update_desktop_file only when on suse.
- Ran spec-cleaner
* Tue Apr  7 2015 g.bluehut@gmail.com
- Add BuildRoot
* Thu Apr  2 2015 g.bluehut@gmail.com
- Dont use the make_install macro so it works for older systems too
* Thu Apr  2 2015 g.bluehut@gmail.com
- Use pkgconfig(x11) instead libX11-devel so it is adaptable to name changes
- In case of versions older or equal to 1110 we have to use the old xorg-x11-devel package
* Thu Apr  2 2015 g.bluehut@gmail.com
- Use libX11-devel instead of xorg-x11-devel meta package as dependency
* Thu Apr  2 2015 g.bluehut@gmail.com
- Install the COPYING file too
* Wed Mar 25 2015 g.bluehut@gmail.com
- update from 0.7.6 to 0.7.8 include:
  - plenty of bugfixes, some important ones were:
  - fixed memory leaks on :restart
  - fixed segmentation fault for long argument lists
  - fixed possible removing files at destination on restoring files from trash manually
  - new color schemes:
  - zenburn
  - improved documentation
  - added several new commands:
  - gf
  - av
  - lstrash
  - include regular expression in search error message that says that it's wrong
  - added support for 256 colors with xterm-like names
  - added several new hilight groups
  - added "not-operator"
* Thu Oct 30 2014 Led <ledest@gmail.com> 0.7.8-1
- 0.7.8
- clean up spec
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- update to 0.7.6:
  - added interactive local filter
  - added external editing of command-line content with 'vicmd'
  - added integration with tmux
  - added options to configure external commands for :apropos, :find, :grep
    and :locate commands
  - added desktop entry file (\*nix only) and updated application icon
- changes from 0.7.5:
  - removed using of libtool in build process on *nix-like systems
  - added parsing of escape codes for the preview pane and less-like view
  - added expand() builtin function
  - added macros that are expanded to register's content
  - added dynamic loading of xlib
  - added 'shortmess' option
  - fixed for redrawing and searching in less-like mode
* Thu Oct 18 2012 pascal.bleser@opensuse.org
- update to 0.7.4: bugfixes
* Fri Mar 30 2012 pascal.bleser@opensuse.org
- update to 0.7.2a: repackaged because of missing files
* Mon Feb 20 2012 puzel@suse.com
- update to 0.7.2
  (see /usr/share/doc/packages/vifm/ChangeLog for details)
- drop vifm-fix_buffer_overflow.patch (fixed upstream)
* Wed Nov 30 2011 pascal.bleser@opensuse.org
- update to 0.7.1
  (see /usr/share/doc/packages/vifm/ChangeLog for details)
* Mon Jun 13 2011 puzel@novell.com
- update to vifm-0.6.1
  - see /usr/share/doc/packages/vifm/ChangeLog for details
- add pkg-config and file-devel to BuildRequires
* Mon Sep 14 2009 puzel@novell.com
- update to vifm-0.5
  * Changed the file size to a human friendly notation.
  * Added ascending and descending sort types.
  * Changed the way symbolic directories are handled.
  * Fixed possible buffer overflow in colorschemes.
  * Fixed transparency in colorschemes.
  * Changed writing to vifmrc file to query user if
    they would like to overwrite a file that has been modified.
  * Added filetype settings for mounting files with fuse-zip.
  * Pauseme script was changed to report errors.
  * Command line input now accepts wide characters and tab completion
    now cycles through all possible matches.
  * ncursesw is now required to build vifm.
* Tue Dec  9 2008 puzel@suse.cz
- fix rpmlint warnings
* Mon Jul 14 2008 puzel@suse.cz
- initial package
